use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007005
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
AIX
Alex
Andrade
Aristotle
BENCHMARKING
Bell
BooK
Book
Bruhat
CRLF
Champoux
Chris
Continsouzas
Dan
Dave
David
Doug
Efros
Ellis
Etheridge
Fish
Flavio
Fuji
Gabor
Gabriel
George
Geraud
Golden
Goro
Graham
Gregoire
Hartzell
Hunt
IEC
III
Ian
Inkster
Ivy
James
John
Karen
Karr
Keedi
KiB
Kim
Kjeldsen
Knop
Lustre
Mark
Martin
MiB
Michael
Miyagawa
NFS
Nigel
Ollis
Pagaltzis
Path
Philippe
Poletti
Rolsky
Roy
SHA
Schwern
Shlomi
Sillitoe
Sluka
Smylers
Steinbrunner
Szabo
Tatsuhiko
Tiny
Toby
UNC
Williams
Yanick
autarch
bingos
book
brainbuz
canonpath
codepoints
cwd
dagolden
dirname
dsteinbrunner
ether
fany
fatalize
flavio
gabiruh
geraud
gfuji
grinnz
haarg
hartzell
ian
iec
james
kB
keedi
lib
lstat
madcityzen
mark
miyagawa
mk
mkpath
mschwern
nigelgregoire
opena
openr
openrw
openw
pagaltzis
perms
plicease
powerman
realpath
regina
rivy
shlomif
si
stat
stringifying
subclasses
szabgab
tobyink
touchpath
unlinked
utf
yanick
김도형
